@@ -15,6 +15,10 @@
 
 """Flax API."""
 
+from .configurations import (
+    config as config,
+)
+
 from . import core
 from . import jax_utils
 from . import linen
@@ -23,4 +27,4 @@ from . import traverse_util
 
 # DO NOT REMOVE - Marker for internal deprecated API.
 # DO NOT REMOVE - Marker for internal logging.
-from .version import __version__
+from .version import __version__
\ No newline at end of file
