@@ -35,6 +35,7 @@ import flax
 from flax import (config, core, errors, serialization, traceback_util,
                   traverse_util)
 from flax.core import Scope
+from flax.core import partial_eval
 from flax.core.frozen_dict import FrozenDict
 from flax.core.scope import (  # pylint: disable=g-multiple-import
     CollectionFilter, DenyList, FrozenVariableDict, Variable, VariableDict,
@@ -65,17 +66,6 @@ TestScope = type('TestScope',
 
 # pylint: disable=protected-access,attribute-defined-outside-init
 
-def _get_value_representation(x: Any) -> 'flax.linen.summary._ValueRepresentation':
-  from flax.linen import summary
-
-  if isinstance(x, (int, float, bool, type(None))) or (
-    isinstance(x, np.ndarray) and np.isscalar(x)):
-    return summary._ObjectRepresentation(x)
-  try:
-    return summary._ArrayRepresentation(jnp.shape(x), jnp.result_type(x))
-  except:
-    return summary._ObjectRepresentation(x)
-
 def _indent(x: str, num_spaces: int):
   indent_str = ' ' * num_spaces
   lines = x.split('\n')
@@ -837,8 +827,7 @@ class Module:
         if filter_fn and filter_fn(self, fun_name):
           self.sow('intermediates', fun_name, y)
       if add_call_info:
-        _args, _kwargs, _y = jax.tree_util.tree_map(
-          _get_value_representation, (args, kwargs, y), is_leaf=lambda x: x is None)
+        _args, _kwargs, _y = flax.linen.summary._represent_tree((args, kwargs, y))
         _context.call_info_stack[-1].calls.append(
           _CallInfo(call_index, scope_path, type(self), fun.__name__, _args, _kwargs, _y))
       return y
@@ -1014,24 +1003,32 @@ class Module:
     cache = _caches.get(root, weakref.WeakValueDictionary())
     _caches[root] = cache
     queue = []
+    preserve_adopted_names = config.flax_preserve_adopted_names
+    if hasattr(self, 'preserve_adopted_names'):
+       preserve_adopted_names = self.preserve_adopted_names
     def adopt_attr_modules(cache, queue, suffix, subvalue):
       if isinstance(subvalue, Module):
+        adopted_name = None
         if subvalue.parent is None:
-          # Module was passed from outside. It needs to be cloned.
-          # Outside modules are named by attachment, not an outer name.
-          object.__setattr__(subvalue, 'name', None)
           # Preserve sharing-by-reference relationships during adoption
           # via cache keyed on unique instance ids.
           key = subvalue._id
+          # Module was passed from outside. It needs to be cloned.
+          # Outside modules are named by attachment, not an outer name,
+          # UNLESS we're using new adopted name policy, in which case an existing
+          # name will be used, as is often supplied by config systems.
+          if preserve_adopted_names:
+            adopted_name = object.__getattribute__(subvalue, 'name')
           if key in cache:
             subvalue = cache[key]
           else:
-            # We must bind to local variable before adding to weakvalue dict.
-            subvalue = subvalue.clone()
+            subvalue = subvalue.clone(name=None)
             cache[key] = subvalue
         if subvalue.name is None:
           object.__setattr__(subvalue, 'parent', self)
-          object.__setattr__(subvalue, 'name', f'{name}{suffix}')
+          if adopted_name is None:
+            adopted_name = f'{name}{suffix}'
+          object.__setattr__(subvalue, 'name', adopted_name)
           queue.append(subvalue)
       return subvalue
     val = _freeze_attr(_map_over_modules_in_tree(
@@ -1074,7 +1071,13 @@ class Module:
   def _name_taken(self,
                   name: str,
                   module: Optional['Module'] = None,
-                  reuse_scopes: bool = False) -> bool:
+                  reuse_scopes: bool = False,
+                  collection: Optional[str] = None) -> bool:
+    # with relaxed naming don't force non-overlap with python attribute names.
+    if config.flax_relaxed_naming:
+      if reuse_scopes:
+        return False
+      return self.scope.name_reserved(name, collection)
     if name in _all_names_on_object(self):
       val = getattr(self, name, None)
       if module is not None and val is module:
@@ -1146,7 +1149,7 @@ class Module:
       raise ValueError(
           'Variables must be initialized in `setup()` or in a method '
           'wrapped in `@compact`')
-    if self._name_taken(name):
+    if self._name_taken(name, collection=col):
       raise errors.NameInUseError('variable', name, self.__class__.__name__)
     v = self.scope.variable(col, name, init_fn, *init_args, unbox=unbox)
     self._state.children[name] = col
@@ -1186,7 +1189,7 @@ class Module:
       raise ValueError(
           'Parameters must be initialized in `setup()` or in a method '
           'wrapped in `@compact`')
-    if self._name_taken(name):
+    if self._name_taken(name, collection='params'):
       raise errors.NameInUseError('param', name, self.__class__.__name__)
     v = self.scope.param(name, init_fn, *init_args, unbox=unbox)
     self._state.children[name] = 'params'
@@ -1367,7 +1370,7 @@ class Module:
             method: Union[Callable[..., Any], str, None] = None,
             mutable: CollectionFilter = False,
             capture_intermediates: Union[bool, Callable[['Module', str], bool]] = False,
-            **kwargs) -> Union[Any, Tuple[Any, FrozenVariableDict]]:
+            **kwargs) -> Union[Any, Tuple[Any, Union[FrozenVariableDict, Dict[str, Any]]]]:
     """Applies a module method to variables and returns output and modified variables.
 
     Note that `method` should be set if one would like to call `apply` on a
@@ -1449,7 +1452,7 @@ class Module:
                        method: Union[Callable[..., Any], str, None] = None,
                        mutable: CollectionFilter = DenyList('intermediates'),
                        capture_intermediates: Union[bool, Callable[['Module', str], bool]] = False,
-                       **kwargs) -> Tuple[Any, FrozenVariableDict]:
+                       **kwargs) -> Tuple[Any, Union[FrozenVariableDict, Dict[str, Any]]]:
     """Initializes a module method with variables and returns output and modified variables.
 
     Args:
@@ -1506,7 +1509,7 @@ class Module:
            method: Union[Callable[..., Any], str, None] = None,
            mutable: CollectionFilter = DenyList('intermediates'),
            capture_intermediates: Union[bool, Callable[['Module', str], bool]] = False,
-           **kwargs) -> FrozenVariableDict:
+           **kwargs) -> Union[FrozenVariableDict, Dict[str, Any]]:
     """Initializes a module method with variables and returns modified variables.
 
     ``init`` takes as first argument either a single ``PRNGKey``, or a dictionary mapping variable collections names to their ``PRNGKeys``, and will call ``method`` (which is the module's ``__call__`` function by default) passing ``*args`` and ``**kwargs``, and returns
@@ -1596,6 +1599,51 @@ class Module:
         **kwargs)
     return v_out
 
+  @traceback_util.api_boundary
+  def lazy_init(self,
+           rngs: Union[PRNGKey, RNGSequences],
+           *args,
+           method: Optional[Callable[..., Any]] = None,
+           mutable: CollectionFilter = DenyList('intermediates'),
+           **kwargs) -> FrozenVariableDict:
+    """Initializes a module without computing on an actual input.
+
+    lazy_init will initialize the variables without doing unnecessary compute.
+    The input data should be passed as a ``jax.ShapeDtypeStruct`` which specifies
+    the shape and dtype of the input but no concrete data.
+
+    Example::
+
+      model = nn.Dense(features=256)
+      variables = model.lazy_init(rng, jax.ShapeDtypeStruct((1, 128), jnp.float32))
+
+    The args and kwargs args passed to ``lazy_init`` can be a mix of
+    concrete (jax arrays, scalars, bools) and abstract (ShapeDtypeStruct) values.
+    Concrete values are only necessary for arguments that affect
+    the initialization of variables. For example, the model might expect
+    a keyword arg that enables/disables a subpart of the model.
+    In this case, an explicit value (True/Flase) should be passed otherwise
+    ``lazy_init`` cannot infer which variables should be initialized.
+
+    Args:
+      rngs: The rngs for the variable collections.
+      *args: arguments passed to the init function.
+      method: An optional method. If provided, applies this method. If not
+        provided, applies the ``__call__`` method.
+      mutable: Can be bool, str, or list. Specifies which collections should be
+        treated as mutable: ``bool``: all/no collections are mutable.
+        ``str``: The name of a single mutable collection. ``list``: A
+        list of names of mutable collections. By default all collections
+        except "intermediates" are mutable.
+      **kwargs: Keyword arguments passed to the init function.
+    Returns:
+      The initialized variable dict.
+    """
+    Module._module_checks(self)
+    def lazy_wrapper(rngs, *args, **kwargs):
+      return self.init(rngs, *args, method=method, mutable=mutable, **kwargs)
+    return partial_eval.lazy_init(lazy_wrapper)(rngs, *args, **kwargs)
+
   @property
   def variables(self) -> VariableDict:
     """Returns the variables in this module."""
@@ -1977,7 +2025,7 @@ def apply(fn: Callable[..., Any], module: Module,
 def init_with_output(fn: Callable[..., Any], module: Module,
                      mutable: CollectionFilter = DenyList('intermediates'),
                      capture_intermediates: Union[bool, Callable[[Module, str], bool]] = False,
-                     ) -> Callable[..., Tuple[Any, FrozenVariableDict]]:
+                     ) -> Callable[..., Tuple[Any, Union[FrozenVariableDict, Dict[str, Any]]]]:
   """Creates an init function to call ``fn`` with a bound module that also returns the function outputs.
 
   Unlike ``Module.init_with_output`` this function returns a new function with the signature
@@ -2038,7 +2086,7 @@ def init_with_output(fn: Callable[..., Any], module: Module,
 def init(fn: Callable[..., Any], module: Module,
          mutable: CollectionFilter = DenyList('intermediates'),
          capture_intermediates: Union[bool, Callable[[Module, str], bool]] = False,
-         ) -> Callable[..., FrozenVariableDict]:
+         ) -> Callable[..., Union[FrozenVariableDict, Dict[str, Any]]]:
   """Creates an init function to call ``fn`` with a bound module.
 
   Unlike ``Module.init`` this function returns a new function with the signature
