@@ -588,7 +588,30 @@ def checkpoint(target: Target,
                methods=None) -> Target:
   """Lifted version of ``jax.checkpoint``.
 
-  This function is aliased to ``lift.remat`` just like ``jax.remat``.
+  Checkpointing is a technique for reducing memory usage by recomputing
+  activations during backpropagation. When training large models, it can be
+  helpful to checkpoint parts of the model to trade off memory usage for
+  additional computation.
+
+  Example::
+
+    >>> import jax
+    >>> import jax.numpy as jnp
+    >>> import flax.linen as nn
+    ...
+    >>> class CheckpointedMLP(nn.Module):
+    ...   @nn.compact
+    ...   def __call__(self, x):
+    ...     CheckpointDense = nn.checkpoint(nn.Dense)
+    ...     x = CheckpointDense(128)(x)
+    ...     x = nn.relu(x)
+    ...     x = CheckpointDense(1)(x)
+    ...     return x
+    ...
+    >>> model = CheckpointedMLP()
+    >>> variables = model.init(jax.random.PRNGKey(0), jnp.ones((1, 16)))
+
+  This function is aliased to ``remat`` just like ``jax.remat``.
 
   Args:
     target: a ``Module`` or a function taking a ``Module``
@@ -616,7 +639,9 @@ def checkpoint(target: Target,
       arguments as static can avoid ConcretizationTypeErrors when tracing, but
       at the cost of more retracing overheads.
     policy: Experimental checkpoint policy, see ``jax.checkpoint``.
-    methods: If `target` is a `Module`, the methods of `Module` to checkpoint.
+    methods: An optional list of method names that will be lifted, if `methods`
+      is None (default) only the `__call__` method will be lifted. If `target`
+      is a function, `methods` is ignored.
 
   Returns:
     A wrapped version of ``target``. When computing gradients intermediate
@@ -841,21 +866,44 @@ def map_variables(
     methods=None) -> Target:
   """Map Variables inside a module.
 
-  Example::
+  ``map_variables`` can be used to transform the variables inside a module
+  both before and after the module is applied. This is useful among other
+  things for masking the weights of a module without having to modify the
+  module itself.
 
-    class OneBitDense(nn.Module):
-      @nn.compact
-      def __call__(self, x):
-        def sign(x):
-          return jax.tree_util.tree_map(jnp.sign, x)
-        MapDense = nn.map_variables(nn.Dense, "params", sign, init=True)
-        return MapDense(4)(x)
+  Example::
+    >>> import jax
+    >>> import jax.numpy as jnp
+    >>> import flax.linen as nn
+    ...
+    >>> class CausalDense(nn.Module):
+    ...   '''A dense layer that masks the weights such that the output is
+    ...   causal, i.e. output i only depends on input <= i.
+    ...   '''
+    ...   features: int
+    ...
+    ...   def apply_mask(self, variables):
+    ...     return (jax.tree_map(jnp.triu, variables)
+    ...             if not self.is_initializing() else variables)
+    ...
+    ...   def setup(self):
+    ...     # temporary class
+    ...     _CausalDense = nn.map_variables(
+    ...       nn.Dense, 'params', self.apply_mask, init=self.is_initializing())
+    ...     self.dense = _CausalDense(features=self.features, use_bias=False)
+    ...
+    ...   def __call__(self, x):
+    ...     return self.dense(x)
+    ...
+    >>> module = CausalDense(features=5)
+    >>> variables = module.init(jax.random.PRNGKey(0), jnp.ones((1, 5)))
 
   Args:
-    target: the function to be transformed.
+    target: the module or function to be transformed.
     mapped_collections: the collection(s) to be transformed.
-    trans_in_fn: creates a view of the target variables.
-    trans_out_fn: transforms the updated variables in the view after mutation.
+    trans_in_fn: modifies the variables before applying the module or function.
+    trans_out_fn: modifies the variables after applying the module or function,
+      it is only applied if either ``init`` or ``mutable`` are not False.
     init: If True, variables are initialized before transformation.
     mutable: If True, the mapped variable collections will be mutable.
     rngs: PRNGSequences added to the transformed scope (default: all).
@@ -901,7 +949,7 @@ def vjp(
     class LearnScale(nn.Module):
       @nn.compact
       def __call__(self, x, y):
-        p = self.param('scale', nn.initializers.zeros, ())
+        p = self.param('scale', nn.initializers.zeros_init(), ())
         return p * x * y
 
     class Foo(nn.Module):
@@ -976,7 +1024,7 @@ def jvp(
     class LearnScale(nn.Module):
       @nn.compact
       def __call__(self, x):
-        p = self.param('test', nn.initializers.zeros, ())
+        p = self.param('test', nn.initializers._init(), ())
         return p * x
 
     class Foo(nn.Module):
@@ -993,7 +1041,7 @@ def jvp(
   Example::
 
     def learn_scale(scope, x):
-      p = scope.param('scale', nn.initializers.zeros, ())
+      p = scope.param('scale', nn.initializers.zeros_init(), ())
       return p * x
 
     def f(scope, x):
