@@ -35,7 +35,7 @@ from absl import flags
 from absl import logging
 from absl.testing import absltest
 
-import tensorflow as tf
+from flax import io
 
 from tensorboard.backend.event_processing import directory_watcher
 from tensorboard.backend.event_processing import event_file_loader
@@ -114,7 +114,7 @@ class Benchmark(absltest.TestCase):
 
   def __init__(self, *args, **kwargs):
     """Wrap test methods in a try-except decorator to delay exceptions."""
-    super(Benchmark, self).__init__(*args, **kwargs)
+    super().__init__(*args, **kwargs)
     for func_name in dir(self):
       if func_name.startswith('assert'):
         func = getattr(self, func_name)
@@ -123,9 +123,9 @@ class Benchmark(absltest.TestCase):
         setattr(self, func_name, patched_func)
 
     # Create target directory if defined.
-    if FLAGS.benchmark_output_dir and not tf.io.gfile.exists(
+    if FLAGS.benchmark_output_dir and not io.exists(
         FLAGS.benchmark_output_dir):
-      tf.io.gfile.makedirs(FLAGS.benchmark_output_dir)
+      io.makedirs(FLAGS.benchmark_output_dir)
 
   # pylint: disable=invalid-name
   def _collect_assert_wrapper(self, *args, fn=None, **kwargs):
@@ -137,7 +137,7 @@ class Benchmark(absltest.TestCase):
 
   def setUp(self):
     """Setup ran before each test."""
-    super(Benchmark, self).setUp()
+    super().setUp()
     self._reported_name = None
     self._reported_wall_time = None
     self._reported_metrics = {}
@@ -146,7 +146,7 @@ class Benchmark(absltest.TestCase):
 
   def tearDown(self):
     """Tear down after each test."""
-    super(Benchmark, self).tearDown()
+    super().tearDown()
     self._report_benchmark_results()
     for message in self._outstanding_fails:
       raise self.failureException(message)
@@ -165,8 +165,8 @@ class Benchmark(absltest.TestCase):
     model_dir_path = os.path.join(model_dir, self._reported_name or
                                   self._get_test_name())
     # Create directories if they don't exist.
-    if not tf.io.gfile.exists(model_dir_path):
-      tf.io.gfile.makedirs(model_dir_path)
+    if not io.exists(model_dir_path):
+      io.makedirs(model_dir_path)
     return model_dir_path
 
   def has_outstanding_fails(self):
@@ -228,7 +228,7 @@ class Benchmark(absltest.TestCase):
 
     # Prefix the name with the class name.
     class_name = type(calling_class).__name__
-    name = '%s.%s' % (class_name, name)
+    name = '{}.{}'.format(class_name, name)
     return name
 
   def _update_reported_name(self):
@@ -277,5 +277,5 @@ class Benchmark(absltest.TestCase):
     benchmark_output_dir = FLAGS.benchmark_output_dir
     if benchmark_output_dir:
       filename = os.path.join(benchmark_output_dir, name + '.json')
-      with tf.io.gfile.GFile(filename, 'w') as fout:
+      with io.GFile(filename, 'w') as fout:
         fout.write(results_str)
